DomSelector class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getResult(String html, {bool isCleanDomTags = false, String cleanDomTags = 'script,style,noscript', List<DomSingleQuery> queries = const []})
→ List<String>
-
-
getResultList(String html, {required String selectorAll, bool isCleanDomTags = false, String cleanDomTags = 'script,style,noscript', List<DomSingleQuery> queries = const []})
→ List<List<String>>
-