QueryResult class
Constructors
- QueryResult({required Attribute attr, required String selector, bool isCleanDomTags = false, String cleanDomTags = 'script,style,noscript, div[id^="pf-"]'})
Properties
- attr → Attribute
-
final
- cleanDomTags → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCleanDomTags → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → String
-
final
Methods
-
getResult(
String html, {String def = '', int index = 0}) → String - Fetch Single Text
-
getResultFromElement(
Element element, {String def = '', int index = 0}) → String - Fetch Single Text
-
getResultList(
String html, {List< QueryResultSingleQuery> singleQueries = const []}) → List<List< String> > - Fetch Multiple
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited